==> openflowplugin-extension-nicira-0.5.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/reg/load/grouping/NxRegLoad.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.nx.reg.load.Dst;
import org.opendaylight.yangtools.yang.common.QName;
import java.math.BigInteger;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegLoadGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-reg-load {
 *     container dst {
 *         choice dst-choice {
 *             case dst-nx-arp-sha-case {
 *                 leaf nx-arp-sha {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-arp-tha-case {
 *                 leaf nx-arp-tha {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-encap-eth-dst-case {
 *                 leaf nx-encap-eth-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-encap-eth-src-case {
 *                 leaf nx-encap-eth-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-ipv6-dst-case {
 *                 leaf nx-ipv6-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-ipv6-src-case {
 *                 leaf nx-ipv6-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsh-mdtype-case {
 *                 leaf nx-nsh-mdtype {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsh-np-case {
 *                 leaf nx-nsh-np {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-1-case {
 *                 leaf nx-nshc-1-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-2-case {
 *                 leaf nx-nshc-2-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-3-case {
 *                 leaf nx-nshc-3-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-4-case {
 *                 leaf nx-nshc-4-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsi-case {
 *                 leaf nx-nsi-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsp-case {
 *                 leaf nx-nsp-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-of-in-port-case {
 *                 leaf of-in-port {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-reg-case {
 *                 leaf nx-reg {
 *                     type identityref;
 *                 }
 *             }
 *             case dst-nx-tun-gpe-np-case {
 *                 leaf nx-tun-gpe-np {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-id-case {
 *                 leaf nx-tun-id {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-ipv4-dst-case {
 *                 leaf nx-tun-ipv4-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-ipv4-src-case {
 *                 leaf nx-tun-ipv4-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-op-case {
 *                 leaf of-arp-op {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-spa-case {
 *                 leaf of-arp-spa {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-tpa-case {
 *                 leaf of-arp-tpa {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-eth-dst-case {
 *                 leaf of-eth-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-eth-src-case {
 *                 leaf of-eth-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-icmp-type-case {
 *                 leaf of-icmp-type {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-ip-dst-case {
 *                 leaf of-ip-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-ip-src-case {
 *                 leaf of-ip-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-metadata-case {
 *                 leaf of-metadata {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-mpls-label-case {
 *                 leaf of-mpls-label {
 *                     type empty;
 *                 }
 *             }
 *         }
 *         leaf start {
 *             type uint16;
 *         }
 *         leaf end {
 *             type uint16;
 *         }
 *         uses dst-choice-grouping;
 *         uses range-grouping;
 *     }
 *     leaf value {
 *         type uint64;
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-load-grouping/nx-reg-load</i>
 *
 * <p>To create instances of this class use {@link org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.NxRegLoadBuilder}.
 * @see org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.NxRegLoadBuilder
 *
 */
public interface NxRegLoad
    extends
    ChildOf<NxActionRegLoadGrouping>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.NxRegLoad>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-reg-load").intern();

    /**
     * Writes value to bits start through end, inclusive, in field dst.
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.nx.reg.load.Dst</code> <code>dst</code>, or <code>null</code> if not present
     */
    Dst getDst();
    
    /**
     * @return <code>java.math.BigInteger</code> <code>value</code>, or <code>null</code> if not present
     */
    BigInteger getValue();

}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/reg/load/grouping/NxRegLoad.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.nx.reg.load.Dst;
import org.opendaylight.yangtools.yang.common.QName;
import java.math.BigInteger;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegLoadGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-reg-load {
 *     container dst {
 *         choice dst-choice {
 *             case dst-nx-arp-sha-case {
 *                 leaf nx-arp-sha {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-arp-tha-case {
 *                 leaf nx-arp-tha {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-encap-eth-dst-case {
 *                 leaf nx-encap-eth-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-encap-eth-src-case {
 *                 leaf nx-encap-eth-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-ipv6-dst-case {
 *                 leaf nx-ipv6-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-ipv6-src-case {
 *                 leaf nx-ipv6-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsh-mdtype-case {
 *                 leaf nx-nsh-mdtype {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsh-np-case {
 *                 leaf nx-nsh-np {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-1-case {
 *                 leaf nx-nshc-1-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-2-case {
 *                 leaf nx-nshc-2-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-3-case {
 *                 leaf nx-nshc-3-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nshc-4-case {
 *                 leaf nx-nshc-4-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsi-case {
 *                 leaf nx-nsi-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-nsp-case {
 *                 leaf nx-nsp-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-of-in-port-case {
 *                 leaf of-in-port {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-reg-case {
 *                 leaf nx-reg {
 *                     type identityref;
 *                 }
 *             }
 *             case dst-nx-tun-gpe-np-case {
 *                 leaf nx-tun-gpe-np {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-id-case {
 *                 leaf nx-tun-id {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-ipv4-dst-case {
 *                 leaf nx-tun-ipv4-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-nx-tun-ipv4-src-case {
 *                 leaf nx-tun-ipv4-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-op-case {
 *                 leaf of-arp-op {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-spa-case {
 *                 leaf of-arp-spa {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-arp-tpa-case {
 *                 leaf of-arp-tpa {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-eth-dst-case {
 *                 leaf of-eth-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-eth-src-case {
 *                 leaf of-eth-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-icmp-type-case {
 *                 leaf of-icmp-type {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-ip-dst-case {
 *                 leaf of-ip-dst {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-ip-src-case {
 *                 leaf of-ip-src {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-metadata-case {
 *                 leaf of-metadata {
 *                     type empty;
 *                 }
 *             }
 *             case dst-of-mpls-label-case {
 *                 leaf of-mpls-label {
 *                     type empty;
 *                 }
 *             }
 *         }
 *         leaf start {
 *             type uint16;
 *         }
 *         leaf end {
 *             type uint16;
 *         }
 *         uses dst-choice-grouping;
 *         uses range-grouping;
 *     }
 *     leaf value {
 *         type uint64;
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-load-grouping/nx-reg-load</i>
 *
 * <p>To create instances of this class use {@link NxRegLoadBuilder}.
 * @see NxRegLoadBuilder
 *
 */
public interface NxRegLoad
    extends
    ChildOf<NxActionRegLoadGrouping>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.NxRegLoad>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-reg-load").intern();

    /**
     * Writes value to bits start through end, inclusive, in field dst.
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.load.grouping.nx.reg.load.Dst</code> <code>dst</code>, or <code>null</code> if not present
     */
    Dst getDst();
    
    /**
     * @return <code>java.math.BigInteger</code> <code>value</code>, or <code>null</code> if not present
     */
    BigInteger getValue();

}
